==> haskell-unliftio-0.2.9.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unliftio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unliftio
version: 0.2.9.0
id: unliftio-0.2.9.0-2mdjx8zy3hcI6UUFcvNMEo
key: unliftio-0.2.9.0-2mdjx8zy3hcI6UUFcvNMEo
license: MIT
copyright: 2017 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman, Francesco Mazzoli
homepage: https://github.com/fpco/unliftio/tree/master/unliftio#readme
synopsis: The MonadUnliftIO typeclass for unlifting monads to IO (batteries included)
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio>
category: Control
abi: 85e08b57e7eb716cf9cd592ebef27740
exposed: True
exposed-modules:
    UnliftIO UnliftIO.Async UnliftIO.Chan UnliftIO.Concurrent
    UnliftIO.Directory UnliftIO.Environment UnliftIO.Exception
    UnliftIO.Foreign UnliftIO.IO UnliftIO.IORef
    UnliftIO.Internals.Async UnliftIO.MVar UnliftIO.Memoize
    UnliftIO.Process UnliftIO.STM UnliftIO.Temporary UnliftIO.Timeout
hidden-modules: Paths_unliftio
import-dirs: /usr/lib/ghc-8.6.3/site-local/unliftio-0.2.9.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/unliftio-0.2.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/unliftio-0.2.9.0
hs-libraries: HSunliftio-0.2.9.0-2mdjx8zy3hcI6UUFcvNMEo
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0 deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1 process-1.6.3.0 stm-2.5.0.0
    time-1.8.0.2 transformers-0.5.5.0 unix-2.7.2.2
    unliftio-core-0.1.2.0-6l4GP0ylCTM6crlVTDgRiK
haddock-interfaces: /usr/share/doc/haskell-unliftio/html/unliftio.haddock
haddock-html: /usr/share/doc/haskell-unliftio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unliftio-0.2.10-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unliftio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unliftio
version: 0.2.10
id: unliftio-0.2.10-6BeTuCwOjOY5nq98Ou3aN7
key: unliftio-0.2.10-6BeTuCwOjOY5nq98Ou3aN7
license: MIT
copyright: 2017 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman, Francesco Mazzoli
homepage: https://github.com/fpco/unliftio/tree/master/unliftio#readme
synopsis: The MonadUnliftIO typeclass for unlifting monads to IO (batteries included)
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio>
category: Control
abi: cbf62d549e398fc0adcdd5fac8f139ad
exposed: True
exposed-modules:
    UnliftIO UnliftIO.Async UnliftIO.Chan UnliftIO.Concurrent
    UnliftIO.Directory UnliftIO.Environment UnliftIO.Exception
    UnliftIO.Foreign UnliftIO.IO UnliftIO.IORef
    UnliftIO.Internals.Async UnliftIO.MVar UnliftIO.Memoize
    UnliftIO.Process UnliftIO.STM UnliftIO.Temporary UnliftIO.Timeout
hidden-modules: Paths_unliftio
import-dirs: /usr/lib/ghc-8.6.3/site-local/unliftio-0.2.10
library-dirs: /usr/lib/ghc-8.6.3/site-local/unliftio-0.2.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/unliftio-0.2.10
hs-libraries: HSunliftio-0.2.10-6BeTuCwOjOY5nq98Ou3aN7
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0 deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1 process-1.6.3.0 stm-2.5.0.0
    time-1.8.0.2 transformers-0.5.5.0 unix-2.7.2.2
    unliftio-core-0.1.2.0-6l4GP0ylCTM6crlVTDgRiK
haddock-interfaces: /usr/share/doc/haskell-unliftio/html/unliftio.haddock
haddock-html: /usr/share/doc/haskell-unliftio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
